# Documentation Pull Request

<!--
Before proceeding, please confirm that:
1. The changes have been discussed with the maintainers
2. A plan has been agreed upon
3. The related issue has been assigned to you
-->

## Description

<!-- Please include a summary of the documentation changes -->

Fixes #<!-- issue number -->

## Checklist

- [ ] I have read the contributing guidelines
- [ ] Documentation renders correctly (if applicable)
- [ ] Links are working (if applicable)
- [ ] Code examples are correct and working (if applicable)
- [ ] Spelling and grammar have been checked
- [ ] My changes follow the documentation style of this project

## Type of Documentation Change

- [ ] New documentation
- [ ] Documentation update
- [ ] Typo fix
- [ ] Other (please describe):

## Additional Notes

<!-- Add any other context about the PR here -->
